@@ -1,3 +1,5 @@
+// -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+// vi: set et ts=4 sw=2 sts=2:
 #include "config.h"
 
 // include this first to see whether it includes all necessary headers itself
@@ -11,12 +13,12 @@
 
 using namespace Dune;
 
- 
+
 template<class K, int n>
 void test_matrix()
 {
   typedef typename ScaledIdentityMatrix<K,n>::size_type size_type;
-  
+
   ScaledIdentityMatrix<K,n> A(1);
   FieldVector<K,n> f;
   FieldVector<K,n> v;
@@ -39,11 +41,14 @@ void test_matrix()
   A.infinity_norm_real();
 
   std::sort(v.begin(), v.end());
-  
+
   // print matrix
   std::cout << A << std::endl;
   // print vector
   std::cout << f << std::endl;
+
+  // Construction of FieldMatrix from ScaledIdentityMatrix
+  FieldMatrix<K,n,n> AFM DUNE_UNUSED = FieldMatrix<K,n,n>(A);
 }
 
 int main()
